if select(2, UnitClass("player")) ~= "PRIEST" then return end
local GetSpellInfo = DrDamage.SafeGetSpellInfo
local GetPrimaryTalentTree = GetPrimaryTalentTree
local UnitExists = UnitExists
local UnitIsFriend = UnitIsFriend
local UnitIsUnit = UnitIsUnit
local UnitHealth = UnitHealth
local UnitHealthMax = UnitHealthMax
local UnitPowerMax = UnitPowerMax
local math_min = math.min
local select = select

function DrDamage:PlayerData()
	self:Print( "Priests are not yet supported by DrDamage." )
	--Health Updates
	self.TargetHealth = { [1] = 0.501, [2] = 0.351, [0.351] = GetSpellInfo(32379) }
	--Shadowfiend 4.0
	self.ClassSpecials[GetSpellInfo(34433)] = function()
		return 0.3 * UnitPowerMax("player",0), false, true
	end
	--Dispersion 4.0
	self.ClassSpecials[GetSpellInfo(47585)] = function()
		return 0.36 * UnitPowerMax("player",0), false, true
	end
	--Dispel Magic 4.0
	self.ClassSpecials[GetSpellInfo(527)] = function()
		--Glyph of Dispel Magic 4.0
		if self:HasGlyph(55677) then
			local heal
			if UnitExists("target") and UnitIsFriend("target","player") then
				heal = 0.03 * UnitHealthMax("target")
			else
				heal = 0.03 * UnitHealthMax("player")
			end
			return heal, true
		end
	end	
--GENERAL
	self.Calculation["PRIEST"] = function ( calculation, ActiveAuras, Talents )
		--Specialization
		local spec = GetPrimaryTalentTree()
		local mastery = calculation.mastery
		if spec == 1 then
			-- Discipline Spec
			-- TODO Minor: Meditation (allows 50% of mana regen from Spirit to continue while in combat)
			if calculation.playerLevel >= 80 then
				-- All absorption increased by 20% plus Mastery bonus.
				local absorbPotency = 1.2 + (mastery * 0.025)
				
				if calculation.school == "Absorb" then
					calculation.dmgM = calculation.dmgM * absorbPotency
				end				
			end
		elseif spec == 2 then
			-- Holy Spec
			-- TODO Minor: Meditation (allows 50% of mana regen from Spirit to continue while in combat)
			
			-- Increase healing by 15%.
			if calculation.school == "Healing" then
				calculation.dmgM = calculation.dmgM * 0.15
			end
			
			if calculation.playerLevel >= 80 then
				-- All direct heals heal for an additional 10% over 6 seconds.
				-- Mastery increases that by 1.25% per point.
				local masteryHoT = .1 + (mastery * 0.0125)
				
				-- TODO: Just adding this in flat for now.  We can make it a hybrid HoT later.
				calculation.dmgM = calculation.dmgM * masteryHoT				
			end
		elseif spec == 3 then
			-- Shadow Spec
			-- Spell damage increased by 25%.  Shadow crit damage increased by 100%.
			calculation.dmgM = calculation.dmgM * 1.25
			
			if calculation.school == "Shadow" then
				calculation.critM = calculation.critM * 2
			end
			
			if calculation.playerLevel >= 80 then
				-- Additional damage from Shadow Orbs due to Mastery.
				local masteryBonus = (mastery * 0.013)
				self.PlayerAura[GetSpellInfo(77487)].Value = self.PlayerAura[GetSpellInfo(77487)].Value + masteryBonus
			end
		end	
		
		if ActiveAuras["Shadowform"] and calculation.school == "Shadow" then
			--Multiplicative - 3.3.3
			calculation.dmgM = calculation.dmgM * 1.15
		end
	end

--TALENTS
	local daicon = "|T" .. select(3,GetSpellInfo(47515)) .. ":16:16:1:-1|t"
	self.Calculation["Divine Aegis"] = function( calculation, value )
		if calculation.canCrit then
			calculation.extraCrit = (value + ((self:GetSetAmount( "Tier 9 - Healing" ) >= 4) and 0.1 or 0)) / (calculation.hits or 1)
			calculation.extraChanceCrit = true
			calculation.extraName = daicon
		end
	end
	self.Calculation["Improved Flash Heal"] = function( calculation, value )
		local target = calculation.target
		if target and UnitHealth(target) ~= 0 and (UnitHealth(target) / UnitHealthMax(target)) <= 0.5 then
			calculation.critPerc = calculation.critPerc + value
		end
	end
	self.Calculation["Test of Faith"] = function( calculation, value )
		local target = calculation.target
		if target and UnitHealth(target) ~= 0 and (UnitHealth(target) / UnitHealthMax(target)) <= 0.5 then
			calculation.dmgM = calculation.dmgM * (1 + value)
		end
	end
--ABILITIES
	self.Calculation["Mind Blast"] = function ( calculation, ActiveAuras, Talents )
		--if ActiveAuras["Shadow Word: Pain"] and Talents["Twisted Faith"] then
		--	--Multiplicative - 3.3.3
 		--	calculation.dmgM = calculation.dmgM * (1 + Talents["Twisted Faith"])
		--end
	end
	self.Calculation["Mind Flay"] = function ( calculation, ActiveAuras, Talents )
		--This is to cancel out using 3 spell hits, so we can use the Blizzard tooltip values instead of dividing with 3
		calculation.bDmgM = (1/3)
		if ActiveAuras["Shadow Word: Pain"] then
 			--Glyph of Mind Flay
 			if self:HasGlyph(55687) then
 				calculation.dmgM_Add = calculation.dmgM_Add + 0.1
 			end
		end
		if self:GetSetAmount( "Tier 9 - Damage" ) >= 4 then
			calculation.critPerc = calculation.critPerc + 5
		end
		if self:GetSetAmount( "Tier 10 - Damage" ) >= 4 then
			calculation.castTime = 2.49
		end
	end
	
	
	self.Calculation["Shadow Word: Pain"] = function ( calculation, ActiveAuras, Talents )
		if ActiveAuras["Shadowform"] then
			calculation.canCrit = true
			calculation.critM = calculation.critM + 0.5
		end
		
		if Talents["Shadowy Apparition"] then
			local shadowy_apparition_icon = "|T" .. select(3,GetSpellInfo(78202)) .. ":16:16:1:-1|t"
		
			calculation.extra = self:ScaleData(0.514)
			calculation.extraDamage = 0.515
			calculation.extraBonus = true
			calculation.extraCanCrit = true --Let's assume this crits for now
			calculation.extraChance =   calculation.hits_dot * Talents["Shadowy Apparition"]
			calculation.extraName = shadowy_apparition_icon
		end
		if self:GetSetAmount( "Tier 10 - Damage" ) >= 2 then
			calculation.critPerc = calculation.critPerc + 5
		end
	end
	self.Calculation["Vampiric Touch"] = function ( calculation, ActiveAuras )
		if ActiveAuras["Shadowform"] then
			calculation.canCrit = true
			calculation.critM = calculation.critM + 0.5
			calculation.customHaste = true
		end
		if self:GetSetAmount( "Tier 9 - Damage" ) >= 2 then
			calculation.eDuration = calculation.eDuration + 6
		end
		if self:GetSetAmount( "Tier 10 - Damage" ) >= 2 then
			calculation.critPerc = calculation.critPerc + 5
		end
	end
	self.Calculation["Devouring Plague"] = function ( calculation, ActiveAuras, Talents )
		if ActiveAuras["Shadowform"] then
			calculation.canCrit = true
			calculation.critM = calculation.critM + 0.5
			calculation.customHaste = true
		end
		if Talents["Improved Devouring Plague"] then
			calculation.dmgM_dd = Talents["Improved Devouring Plague"]
			calculation.hybridDotDmg = (calculation.minDam + calculation.maxDam) / 2
			calculation.SPBonus_dot = calculation.SPBonus
			calculation.canCrit = true
		end
		if self:GetSetAmount( "Tier 8 - Damage" ) >= 2 then
			calculation.dmgM_custom = true
			local dmgM = calculation.dmgM_dot * calculation.dmgM * (1 + calculation.dmgM_Add + calculation.dmgM_dot_Add)
			calculation.dmgM_dot_Add = calculation.dmgM_dot_Add + 0.15
			calculation.dmgM_dot = calculation.dmgM_dot * calculation.dmgM * (1 + calculation.dmgM_Add + calculation.dmgM_dot_Add)
			calculation.dmgM = dmgM
		end
		if self:GetSetAmount( "Tier 10 - Damage" ) >= 2 then
			calculation.critPerc = calculation.critPerc + 5
		end
	end
	self.Calculation["Renew"] = function ( calculation, _, Talents )
		if Talents["Empowered Renew"] then
			calculation.dmgM_dd = Talents["Empowered Renew"]
			--Multiplicative - 3.3.3
			if self:GetSetAmount( "Tier 9 - Healing" ) >= 4 then
				calculation.dmgM_dd = calculation.dmgM_dd * 1.1
			end
			calculation.hybridDotDmg = ((calculation.minDam + calculation.maxDam) / 2)
			calculation.SPBonus_dot = calculation.SPBonus
			calculation.canCrit = true
		end
		--Glyph of Renew
		if self:HasGlyph(55674) then
			calculation.eDuration = calculation.eDuration - 3
			--BUG: Talent effect are reduced? (Spiritual Healing, Twin Disciplines, Improved Renew. NOT Focused Power, Blessed Resilience)
			if Talents["Empowered Renew"] then
				calculation.dmgM_custom = true
				calculation.dmgM_dot = calculation.dmgM_dot * calculation.dmgM * (1 + (4/5) * (calculation.dmgM_Add + calculation.dmgM_dot_Add))
				calculation.dmgM = calculation.dmgM * (1 + calculation.dmgM_Add + calculation.dmgM_dd_Add) 			
			else
				calculation.dmgM_Add = calculation.dmgM_Add * (4/5)
			end		
		end		
	end
	self.Calculation["Holy Nova"] = function( calculation )
		--Glyph of Holy Nova (additive - 3.3.3)
		if self:HasGlyph(55683) then
			calculation.dmgM_Add = calculation.dmgM_Add + 0.2
		end
	end
	self.Calculation["Lightwell"] = function( calculation )
		--Glyph of Lightwell (TODO: A/M?)
		if self:HasGlyph(55673) then
			calculation.dmgM_Add = calculation.dmgM_Add + 0.2
		end
	end
	self.Calculation["Shadow Word: Death"] = function( calculation, ActiveAuras, Talents )
		--Glyph of Shadow Word: Death (multiplicative - 3.3.3)
		if Talents["Mind Melt"] then
			if UnitHealth("target") ~= 0 and (UnitHealth("target") / UnitHealthMax("target")) <= 0.35 then
				calculation.dmgM = calculation.dmgM * (1 + Talents["Mind Melt"])
			end
		end
		if self:GetSetAmount( "Tier 7 - Damage" ) >= 4 then
			calculation.critPerc = calculation.critPerc + 10
		end
	end
	self.Calculation["Smite"] = function( calculation, ActiveAuras )
		--Glyph of Smite (multiplicative - 3.3.3)
		if self:HasGlyph(55692) and ActiveAuras["Holy Fire"] then
 			calculation.dmgM = calculation.dmgM * 1.2
		end
	end
	self.Calculation["Prayer of Healing"] = function( calculation )
		--Glyph of Prayer of Healing
		if self:HasGlyph(55680) then
			calculation.hybridDotDmg = 0.2 * 0.5 * (calculation.minDam + calculation.maxDam)
			calculation.SPBonus_dot = 0.2 * calculation.SPBonus
			calculation.eDuration = 6
			calculation.sTicks = 3
		end
		if self:GetSetAmount( "Tier 8 - Healing" ) >= 2 then
			calculation.critPerc = calculation.critPerc + 10
		end
	end
	local glyph = GetSpellInfo(52817)
	local glyphicon = "|TInterface\\Icons\\INV_Glyph_MajorPriest:16:16:1:-1|t"
	self.Calculation["Power Word: Shield"] = function( calculation, _, Talents )
		--TODO: 4T10 A/M?
		--PW: Shield - (1 + 0.05 * IPWS) * (1 + 0.02 * SpiritualHealing + 0.01 * Twin Disciplines + 0.02 * Focused Power). NOTE: Blessed Resilience doesn't apply.
		local pwsMod = self.healingMod * (calculation.dmgM_absorb or 1) * (1 + (Talents["Improved Power Word: Shield"] or 0)) * (1 + (Talents["Spiritual Healing"] or 0) + (Talents["Twin Disciplines"] or 0) + (Talents["Focused Power"] or 0) + (self:GetSetAmount( "Tier 10 - Healing" ) >= 4 and 0.05 or 0))
		local auraMod = calculation.dmgM
		calculation.dmgM_custom = true
		calculation.dmgM = pwsMod
		--Glyph of Power Word: Shield -- (1 + 0.05 * IPWS + 0.01 * Twin Disciplines) * (1 + 0.01 * Blessed Resilience) * (1 + 0.02 * Focused Power). NOTE: Spiritual Healing doesn't apply.
		if self:HasGlyph(55672) then
			--TODO: 4T10 A/M?
			local glyphMod = (1 + (Talents["Improved Power Word: Shield"] or 0) + (Talents["Twin Disciplines"] or 0) + (self:GetSetAmount( "Tier 10 - Healing" ) >= 4 and 0.05 or 0)) * (1 + (Talents["Blessed Resilience"] or 0)) * (1 + (Talents["Focused Power"] or 0))
			calculation.extraCrit = (0.2 / pwsMod) * auraMod * glyphMod
			calculation.extraCanCrit = true
			calculation.extraName = glyph
			if Talents["Divine Aegis Bonus"] then
				calculation.extraName = glyphicon .. "+" .. daicon
				calculation.extraCritEffect = Talents["Divine Aegis Bonus"] * ((self:GetSetAmount( "Tier 9 - Healing" ) >= 4) and 1.1 or 1)
			end
		end
	end
	self.Calculation["Circle of Healing"] = function( calculation )
		--Glyph of Circle of Healing
		if self:HasGlyph(55675) then
			calculation.aoe = calculation.aoe + 1
		end
		--TODO: Additive/multiplicative?
		if self:GetSetAmount( "Tier 10 - Healing" ) >= 4 then
			calculation.dmgM_Add = calculation.dmgM_Add + 0.1
		end		
	end
	self.Calculation["Divine Hymn"] = function( calculation )
		calculation.dmgM = calculation.dmgM * 1.1
		if calculation.targets > 1 then
			calculation.hits = calculation.hits * math_min(3, calculation.targets)
		end
	end
	self.Calculation["Prayer of Mending"] = function( calculation )
		if self:GetSetAmount( "Tier 7 - Healing" ) >= 2 then
			calculation.hits = calculation.hits + 1
		end
		--Multiplicative - 3.3.3
		if self:GetSetAmount( "Tier 9 - Healing" ) >= 2 then
			calculation.dmgM = calculation.dmgM * 1.2
		end
	end
	self.Calculation["Flash Heal"] = function( calculation )
		if self:GetSetAmount( "Tier 10 - Healing" ) >= 2 then
			--TODO: Support DA + set bonus?
			if calculation.extraCrit then
				calculation.extraCrit = nil
				calculation.extraChanceCrit = nil
			end
			calculation.extraAvg = (1/3)
			calculation.extraChance = (1/3)
			calculation.extraTicks = 3
			calculation.extraName = "2T10"
		end
	end

--SETS
	self.SetBonuses["Tier 7 - Damage"] = { 40454, 40456, 40457, 40458, 40459, 39521, 39523, 39528, 39529, 39530 }
	self.SetBonuses["Tier 7 - Healing"] = { 40445, 40447, 40448, 40449, 40450, 39514, 39515, 39517, 39518, 39519 }
	self.SetBonuses["Tier 8 - Damage"] = { 46163, 46165, 46168, 46170, 46172, 45391, 45392, 45393, 45394, 45395 }
	self.SetBonuses["Tier 8 - Healing"] = { 46188, 46190, 46193, 46195, 46197, 45386, 45387, 45388, 45389, 45390 }
	self.SetBonuses["Tier 9 - Damage"] = { 48072, 48073, 48074, 48075, 48076, 48097, 48098, 48099, 48100, 48101, 48078, 48077, 48081, 48079, 48080, 48085, 48086, 48082, 48084, 48083, 48095, 48096, 48092, 48094, 48093, 48088, 48087, 48091, 48089, 48090 }
	self.SetBonuses["Tier 9 - Healing"] = { 47914, 47936, 47980, 47981, 47982, 48067, 48068, 48069, 48070, 48071, 48065, 48066, 48064, 48063, 48062, 48058, 48057, 48059, 48060, 48061, 47984, 47983, 47985, 47986, 47987, 48035, 48037, 48033, 48031, 48029 }
	self.SetBonuses["Tier 10 - Damage"] = { 50392, 50391, 50396, 50393, 50394, 51255, 51184, 51256, 51183, 51257, 51182, 51258, 51181, 51259, 51180 }
	self.SetBonuses["Tier 10 - Healing"] = { 50766, 50765, 50769, 50768, 50767, 51260, 51179, 51261, 51178, 51262, 51177, 51263, 51176, 51264, 51175 }
--AURA
--Player
	--Shadowform
	self.PlayerAura[GetSpellInfo(15473)] = { School = "Shadow", ActiveAura = "Shadowform", ID = 15473 }
	--Shadow Orb
	self.PlayerAura[GetSpellInfo(77487)] = { Value = 0.1, Apps = 3, ID = 77487, Spells = 8092 }
	--Empowered Shadow
	self.PlayerAura[GetSpellInfo(95799)] = { Value = 0.1, ID = 95799, Spells = { 15407, 2944, 589, 34914 } }
	--Borrowed time
	self.PlayerAura[GetSpellInfo(59891)] = { Update = true }	
	--Surge of Light
	self.PlayerAura[GetSpellInfo(33151)] = { Update = true }
	--Serendipity
	self.PlayerAura[GetSpellInfo(63730)] = { Spells = { 2060, 596 }, Update = true }
	--Inner Focus
	self.PlayerAura[GetSpellInfo(14751)] = { School = "All", Value = 25, ModType = "critPerc", ID = 14751, NoManual = true }
--Target
	--Grace
	self.TargetAura[GetSpellInfo(47516)] = { School = "Healing", Value = 0.03, Apps = 3, SelfCastBuff = true, ID = 47516 }
	--Shadow Word: Pain
	self.TargetAura[GetSpellInfo(589)]   = { ActiveAura = "Shadow Word: Pain", Spells = { 8092, 15407 }, ID = 589 }
	--Holy Fire
	self.TargetAura[GetSpellInfo(14914)] = { Spells = 585, ActiveAura = "Holy Fire", ID = 14914 }
	--Divine Hymn
	self.TargetAura[GetSpellInfo(64844)] = { School = "Healing", Value = 0.1, Not = "Divine Hymn", NoManual = true }
--Custom
	--Weakened Soul
	self.TargetAura[GetSpellInfo(6788)] = { Spells = { 47540, 2061, 2060 }, ID = 6788, ModType =
		function( calculation, _, Talents )
			if Talents["Renewed Hope"] and calculation.healingSpell then
				calculation.critPerc = calculation.critPerc + Talents["Renewed Hope"]
			end
		end
	}

	--SPELLS
	self.spellInfo = {
		[GetSpellInfo(15407)] = {
					-- Checked in 4.0.3
					["Name"] = "Mind Flay",
					["ID"] = 15407,
					["Data"] = { 0.177, 0, 0.257 },
					[0] = { School = "Shadow",  Hits = 3, sTicks = 1, Channeled = 3 },
					[1] = { 0, 0 },
		},
		[GetSpellInfo(2944)] = {
					-- Checked in 4.0.3
					["Name"] = "Devouring Plague",
					["ID"] = 2944,
					["Data"] = { 0.164, 0, 0.185 },
					[0] = { School = "Shadow", eDot = true, Leech = 0.15, eDuration = 24, Hits = 8, Cooldown = 24, sTicks = 3, DotLeech = true, },
					[1] = { 0, 0 },
		},
		[GetSpellInfo(589)] = {
					-- Checked in 4.0.3
					["Name"] = "Shadow Word: Pain",
					["ID"] = 589,
					["Data"] = { 0.332, 0, 0.095 },
					[0] = { School = "Shadow", eDot = true, eDuration = 18 , sTicks = 3 },
					[1] = { 0, 0 },
		},
		[GetSpellInfo(34914)] = {
					-- Checked in 4.0.3
					["Name"] = "Vampiric Touch",
					["ID"] = 34914,
					["Data"] = { 0.115, 0, 0.4 },
					[0] = { School = "Shadow", eDot = true, eDuration = 15, sTicks = 3, },
					[1] = { 0, 0 },
		},
		[GetSpellInfo(32379)] = {
					-- Checked in 4.0.3
					["Name"] = "Shadow Word: Death",
					["ID"] = 32379,
					["Data"] = { 0.319, 0, 0.282 },
					[0] = { School = "Shadow",  Cooldown = 12, },
					[1] = { 0, 0 },
		},
		[GetSpellInfo(8092)] = {
					-- Checked in 4.0.3
					["Name"] = "Mind Blast",
					["ID"] = 8092,
					["Data"] = { 1.119, 0.055, 0.429 },
					[0] = { School = "Shadow", Cooldown = 8 },
					[1] = { 0, 0 },
		},
		[GetSpellInfo(17)] = {
					-- Checked in 4.0.3
					["Name"] = "Power Word: Shield",
					["ID"] = 17,
					["Data"] = { 4.13, 0, 0 },
					[0] = { School = { "Holy", "Healing", "Absorb" }, Cooldown = 4, NoDPS = true, NoDoom = true, NoSchoolTalents = true, NoTypeTalents = true },
					[1] = { 0, 0 },
		},
		[GetSpellInfo(2050)] = {
					-- Checked in 4.0.3
					["Name"] = "Heal",
					["ID"] = 2050,
					["Data"] = { 3.59, 0.15, 0.362 },
					[0] = { School = { "Holy", "Healing" },  castTime = 3, },
					[1] = { 0, 0 },
		},
		[GetSpellInfo(2060)] = {
					-- Checked in 4.0.3
					["Name"] = "Greater Heal",
					["ID"] = 2060,
					["Data"] = { 9.564, 0.15, 0.967 },
					[0] = { School = { "Holy", "Healing" },  castTime = 3, },
					[1] = { 0, 0 },
		},
		[GetSpellInfo(596)] = {
					-- Checked in 4.0.3
					["Name"] = "Prayer of Healing",
					["ID"] = 596,
					["Data"] = { 3.951, 0.055, 0.4 },
					[0] = { School = { "Holy", "Healing" },  castTime = 3, AoE = 5 },
					[1] = { 0, 0 },
		},
		[GetSpellInfo(34861)] = {
					-- Checked in 4.0.3
					["Name"] = "Circle of Healing",
					["ID"] = 34861,
					["Data"] = { 1.978, 0.1, 0.2 },
					[0] = { School = { "Holy", "Healing" }, sFactor = 0.5,  AoE = 5 },
					[1] = { 0, 0 },
		},
		[GetSpellInfo(2061)] = {
					-- Checked in 4.0.3
					["Name"] = "Flash Heal",
					["ID"] = 2061,
					["Data"] = { 7.174, 0.15, 0.725 },
					[0] = { School = { "Holy", "Healing" },  },
					[1] = { 0, 0 },
		},
		[GetSpellInfo(19236)] = {
					-- Checked in 4.0.3
					["Name"] = "Desperate Prayer",
					["ID"] = 19236,
					["Data"] = { 5.646, 0.165, 0.571 },
					[0] = { School = { "Holy", "Healing" },  Cooldown = 120, NoDoom = true, SelfHeal = true, },
					[1] = { 0, 0 },
		},
		[GetSpellInfo(139)] = {
					-- Checked in 4.0.3
					["Name"] = "Renew",
					["ID"] = 139,
					["Data"] = { 1.29, 0, 0.131 },
					[0] = { School = { "Holy", "Healing" }, eDot = true, eDuration = 15, sTicks = 3, },
					[1] = { 0, 0 },
		},
		[GetSpellInfo(32546)] = {
					-- Checked in 4.0.3
					["Name"] = "Binding Heal",
					["ID"] = 32546,
					["Data"] = { 5.746, 0.25, 0.544 },
					[0] = { School = { "Holy", "Healing" }, },
					[1] = { 0, 0 },
		},
		[GetSpellInfo(33076)] = {
					-- Checked in 4.0.3
					["Name"] = "Prayer of Mending",
					["ID"] = 33076,
					["Data"] = { 3.144, 0, 0.318 },
					[0] = { School = { "Holy", "Healing" }, Cooldown = 10, Hits = 5, NoDPS = true, NoPeriod = true },
					[1] = { 0, 0 },
		},
		[GetSpellInfo(585)] = {
					-- Checked in 4.0.3
					["Name"] = "Smite",
					["ID"] = 585,
					["Data"] = { 0.733, 0.115, 0.714 },
					[0] = { School = "Holy",  castTime = 2.5, },
					[1] = { 0, 0 },
		},
		[GetSpellInfo(14914)] = {
					-- Checked in 4.0.3
					["Name"] = "Holy Fire",
					["ID"] = 14914,
					["Data"] = { 1.0829, 0.238, 0.571, 0.054, 0, 0.024 },
					[0] = { School = "Holy",  castTime = 2, Cooldown = 10, eDuration = 7, sTicks = 1, dotFactor = 0.168, },
					[1] = { 0, 0 },
		},
		[GetSpellInfo(23455)] = {
					-- Checked in 4.0.3
					["Name"] = "Holy Nova",
					["ID"] = 23455,
					["Data"] = { 1.94, 0.15, 0.196 },
					["Text1"] = GetSpellInfo(23455),
					["Text2"] = GetSpellInfo(23455), 
					[0] = { School = { "Holy", "Healing", "Holy Nova Heal" }, AoE = 5 },
					[1] = { 0, 0 },
			["Secondary"] = {
					["Name"] = "Holy Nova",
					["ID"] = 15237,
					["Data"] = { 0.316, 0.15, 0.143 },
					["Text1"] = GetSpellInfo(23455),
					["Text2"] = GetSpellInfo(15237),					
					[0] = { School = { "Holy", "Holy Nova Damage" }, AoE = true },
					[1] = { 0, 0 },
			}
		},
		[GetSpellInfo(724)] = {
					-- Checked in 4.0.3
					["Name"] = "Lightwell",
					["ID"] = 724,
					["Data"] = { 3.045, 0, 0 },
					[0] = { School = { "Holy", "Healing" }, Cooldown = 180, eDot = true, eDuration = 6, sTicks = 2, Stacks = 10 },
					[1] = { 0, 0 },
		},
		[GetSpellInfo(64843)] = {
					-- Checked in 4.0.3
					["Name"] = "Divine Hymn",
					["ID"] = 64843,
					["Data"] = { 4.242, 0, 0.429 },
					[0] = { School = { "Holy", "Healing" }, castTime = 8, Hits = 4, Cooldown = 480, Channeled = 8, canCrit = true },
					[1] = { 0, 0 },
		},
		[GetSpellInfo(48045)] = {
					-- Checked in 4.0.3
					["Name"] = "Mind Sear",
					["ID"] = 48045,
					["Data"] = { 0.1, 0.080, 0.114 },
					[0] = { School = "Shadow", Hits = 5, castTime = 5, Channeled = 5, AoE = true },
					[1] = { 0, 0 },
		},
		[GetSpellInfo(47540)] = {
					-- Checked in 4.0.3
					["Name"] = "Penance",
					["ID"] = 47750,
					["Data"] = { 2.65, 0.122, 0.268 },
					[0] = { School = { "Holy", "Healing" }, Cooldown = 12,  Hits = 3, castTime = 2, Channeled = 2 },
					[1] = { 0, 0 },
			["Secondary"] = {
					["Name"] = "Penance",
					["ID"] = 47666,
					["Data"] = { 0.788, 0.122, 0.458 },
					[0] = { School = "Holy", Cooldown = 12,  Hits = 3, castTime = 2, Channeled = 2, },
					[1] = { 0, 0 },
			}
		},
	}
	self.talentInfo = {
	--SHADOW:
		--Improved Shadow Word: Pain (additive - 3.3.3; updated for 4.0.3)
		[GetSpellInfo(15275)] = { 	[1] = { Effect = 0.03, Spells = "Shadow Word: Pain" }, },
		--Improved Mind Blast (updated for 4.0.3)
		[GetSpellInfo(15273)] = { 	[1] = { Effect = -0.5, Spells = "Mind Blast", ModType = "cooldown" }, },
		--Mind Melt (updated for 4.0.3)
		[GetSpellInfo(14910)] = {	[1] = { Effect = 0.15, Spells = { "Shadow Word: Death" }, ModType = "Mind Melt", }, },
		--Improved Devouring Plague (additive - 3.3.3)
		[GetSpellInfo(63625)] = {	[1] = { Effect = 0.05, Spells = "Devouring Plague" },
									[2] = { Effect = 0.10, Spells = "Devouring Plague", ModType = "Improved Devouring Plague", }, },
		--Twisted Faith (multiplicative - 3.3.3; updated for 4.0.3)
		--TODO: Add the Spirit-to-hit component of Twisted Faith (if it doesn't happen on the character sheet)
		[GetSpellInfo(47573)] = {	[1] = { Effect = 0.01, Spells = "Shadow", }, },
		--Shadowy Apparition (updated for 4.0.3)
		[GetSpellInfo(78202)] = {	[1] = { ModType = "Shadowy Apparition" }, },
	--HOLY:
		--Improved Renew (additive - 3.3.3)
		[GetSpellInfo(14908)] = { 	[1] = { Effect = 0.05, Spells = "Renew" }, },
		--Searing Light (additive - 3.3.3)
		[GetSpellInfo(14909)] = { 	[1] = { Effect = 0.05, Spells = { "Smite", "Holy Fire", "Penance", "Holy Nova Damage" } }, },
		--Spiritual Healing (additive - 3.3.3)
		[GetSpellInfo(14898)] = {	[1] = { Effect = 0.02, Spells = "Healing", },
									[2] = { Effect = 0.02, Spells = "Power Word: Shield", ModType = "Spiritual Healing" }, },
		--Blessed Resilience (multiplicative, additive on Lightwell - 3.3.3)
		[GetSpellInfo(33142)] = {	[1] = { Effect = 0.01, Spells = "Healing", Not = "Lightwell", Multiply = true, },
									[2] = { Effect = 0.01, Spells = "Lightwell" },
									[3] = { Effect = 0.01, Spells = "Power Word: Shield", ModType = "Blessed Resilience" }, },
		--Empowered Healing (additive - 3.3.3)
		[GetSpellInfo(33158)] = { 	[1] = { Effect = 0.08, Spells = "Greater Heal", ModType = "SpellDamage", },
									[2] = { Effect = 0.04, Spells = { "Flash Heal", "Binding Heal" }, ModType = "SpellDamage", }, },
		--Empowered Renew (multiplicative - 3.3.3)
		[GetSpellInfo(63534)] = {	[1] = { Effect = 0.05, Spells = "Renew", ModType = "SpellDamage", Multiply = true, },
									[2] = { Effect = 0.05, Spells = "Renew", ModType = "Empowered Renew", }, },
		--Divine Providence (additive - 3.3.3 - Checked Holy Nova and PoM)
		[GetSpellInfo(47562)] = { 	[1] = { Effect = 0.02, Spells = { "Circle of Healing", "Binding Heal", "Divine Hymn", "Holy Nova Heal", "Prayer of Healing", "Prayer of Mending" }, },
									[2] = { Effect = -0.6, Spells = "Prayer of Mending", ModType = "cooldown" }, },
		--Test of Faith (multiplicative - 3.3.3)
		[GetSpellInfo(47558)] = {	[1] = { Effect = 0.04, Spells = "Healing", ModType = "Test of Faith", }, },
	--DISCIPLINE:
		--Improved Power Word: Shield (multiplicative - 3.3.3)
		[GetSpellInfo(14748)] = { 	[1] = { Effect = 0.05, Spells = "Power Word: Shield", ModType = "Improved Power Word: Shield", Multiply = true }, },
		--Twin Disciplines (additive - 3.3.3, applies to Mind Flay, not Mind Sear)
		[GetSpellInfo(47586)] = { 	[1] = { Effect = 0.01, Spells = { "Shadow Word: Pain", "Renew", "Holy Nova", "Prayer of Mending", "Devouring Plague", "Shadow Word: Death", "Desperate Prayer", "Circle of Healing", "Penance", "Mind Flay" }, },
									[2] = { Effect = 0.01, Spells = "Power Word: Shield", ModType = "Twin Disciplines" }, },
		--Focused Power (multiplicative, additive on PW:S and Lightwell - 3.3.3)
		[GetSpellInfo(33190)] = {	[1] = { Effect = 0.02, Spells = "All", Not = "Lightwell", Multiply = true },
									[2] = { Effect = 0.02, Spells = "Lightwell" },
									[3] = { Effect = 0.02, Spells = "Power Word: Shield", ModType = "Focused Power" }, },
		--Soul Warding
		[GetSpellInfo(63574)] = {	[1] = { Effect = -4, Spells = "Power Word: Shield", ModType = "cooldown" }, },
		--Improved Flash Heal
		[GetSpellInfo(63504)] = {	[1] = { Effect = { 4, 7, 10 }, Spells = "Flash Heal", ModType = "Improved Flash Heal" }, },
		--Renewed Hope
		[GetSpellInfo(57472)] = {	[1] = { Effect = 2, Spells = { "Flash Heal", "Greater Heal", "Penance" }, ModType = "Renewed Hope" }, },
		--Borrowed Time (additive - 3.3.3)
		[GetSpellInfo(52795)] = {	[1] = { Effect = 0.08, Spells = "Power Word: Shield", ModType = "SpellDamage" }, },
		--Divine Aegis
		[GetSpellInfo(47515)] = {	[1] = { Effect = 0.1, Spells = "Healing", Not = "Lightwell", ModType = "Divine Aegis", },
									[2] = { Effect = 0.1, Spells = "Power Word: Shield", ModType = "Divine Aegis Bonus" }, },
		
		}
end